﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Drawing.Drawing2D;

namespace Kresleni
{
    public partial class Form1 : Form
    {
        const int LineTool = 0;
        const int RectangleTool = 1;
        const int EllipseTool = 2;

        public Form1()
        {
            InitializeComponent();
            pictureBox_SizeChanged(null, null);
            comboBox1.SelectedIndex = EllipseTool;
        }

        private void draw(Graphics g,
                          Pen p,
                          Brush b,
                          int x1, int y1, int x2, int y2,
                          int tool)
        {
            if (x2 < x1) { int t = x2; x2 = x1; x1 = t; }
            if (y2 < y1) { int t = y2; y2 = y1; y1 = t; }

            switch (tool)
            {
                case LineTool:
                    g.DrawLine(p, x1, y1, x2, y2);
                    /*
                    if (b != null)
                    {
                        Point[] a =
                        {
                            new Point (x1-1, y1),
                            new Point (x1+1, y1),
                            new Point (x2-1, y2),
                            new Point (x2+1, y2)
                        };
                        g.FillPolygon(b, a);
                    }
                    */
                    break;
                case RectangleTool:
                    if (b != null)
                        g.FillRectangle(b, x1, y1, x2 - x1, y2 - y1);
                    g.DrawRectangle(p, x1, y1, x2 - x1, y2 - y1);
                    break;
                case EllipseTool:
                    if (b != null)
                        g.FillEllipse(b, x1, y1, x2 - x1, y2 - y1);
                    g.DrawEllipse(p, x1, y1, x2 - x1, y2 - y1);
                    break;
            }
        }

        private void pictureBox_SizeChanged(object sender, EventArgs e)
        {
            int w = pictureBox.ClientSize.Width;
            int h = pictureBox.ClientSize.Height;
            if (w > 0 && h > 0)
            {
                Bitmap t = null;
                if (pictureBox.Image != null)
                {
                    t = new Bitmap(pictureBox.Image);
                    w = Math.Max(w, pictureBox.Image.Width);
                    h = Math.Max(h, pictureBox.Image.Height);
                }

                pictureBox.Image = new Bitmap(w, h);

                Graphics g = Graphics.FromImage(pictureBox.Image);
                Brush b = Brushes.White;
                g.FillRectangle(b, 0, 0, w, h);

                if (t != null)
                   g.DrawImage(t, 0, 0);
            }
        }



        private void runMenu_Click(object sender, EventArgs e)
        {
            Graphics g = Graphics.FromImage (pictureBox.Image);
            Pen p = Pens.Red;
            g.DrawLine (p, 0, 0, 100, 200);
            pictureBox.Invalidate ();
        }

        private int X0, Y0;
        private bool stisknuto = false;
        private Bitmap save;

        private void pictureBox_MouseDown(object sender, MouseEventArgs e)
        {
            X0 = e.X;
            Y0 = e.Y;
            stisknuto = true;
            save = new Bitmap (pictureBox.Image);
        }

        private void pictureBox_MouseMove(object sender, MouseEventArgs e)
        {
            if (stisknuto)
            {
                Graphics g = Graphics.FromImage(pictureBox.Image);
                g.DrawImage(save, 0, 0);
                Pen p = new Pen(Color.Blue);
                // g.DrawLine(p, X0, Y0, e.X, e.Y);
                draw(g, p, null, X0, Y0, e.X, e.Y, comboBox1.SelectedIndex); 
                pictureBox.Invalidate();
            }
        }


        private void pictureBox_MouseUp(object sender, MouseEventArgs e)
        {
            if (stisknuto)
            {
                stisknuto = false;
                Graphics g = Graphics.FromImage(pictureBox.Image);
                g.DrawImage(save, 0, 0);
                // g.DrawLine(pen, X0, Y0, e.X, e.Y);
                // g.FillEllipse(brush, X0, Y0, e.X - X0, e.Y - Y0);
                // g.DrawEllipse(pen, X0, Y0, e.X - X0, e.Y - Y0);
                draw(g, pen, brush, X0, Y0, e.X, e.Y, comboBox1.SelectedIndex);
                pictureBox.Invalidate();
            }
        }

        Pen pen = new Pen(Color.SlateGray);
        Brush brush = new SolidBrush (Color.SlateGray);

        private void panel1_MouseDown(object sender, MouseEventArgs e)
        {
            // Control panel = (Control) sender;
            Control panel = sender as Control;
            if (e.Button == MouseButtons.Left)
                pen = new Pen(panel.BackColor);
            else if (e.Button == MouseButtons.Right)
            {
                brush = new SolidBrush(panel.BackColor);
                /*
                // using System.Drawing.Drawing2D;
                brush = new LinearGradientBrush
                        (
                          new Point (0, 0),
                          new Point (40, 0),
                          pen.Color,
                          panel.BackColor
                        );
                */
            }
            else if (e.Button == MouseButtons.Middle)
            {
                colorDialog1.Color = panel.BackColor;
                if (colorDialog1.ShowDialog() == DialogResult.OK)
                    panel.BackColor = colorDialog1.Color;
                pen = new Pen(panel.BackColor);
            }
            comboBox1_SelectedIndexChanged(null, null);
        }

        private void quitMenu_Click(object sender, EventArgs e)
        {
            this.Close ();
        }

        int cnt = 2;

        private void newButtonMenu_Click(object sender, EventArgs e)
        {
            Panel p = new Panel();
            // p.Parent = toolPanel;
            toolPanel.Controls.Add (p);
            p.BackColor = Color.Blue;

            cnt ++;
            p.Left = panel1.Left + (cnt - 1) * (panel2.Left - panel1.Left);
            p.Top = panel1.Top;
            p.Width = panel1.Width;
            p.Height = panel1.Height;

            p.MouseDown += this.panel1_MouseDown;
        }

        private void comboBox1_SelectedIndexChanged(object sender, EventArgs e)
        {
            int w = preview.ClientSize.Width;
            int h = preview.ClientSize.Height;
            preview.Image = new Bitmap(w, h);

            Graphics g = Graphics.FromImage(preview.Image);
            Brush b = Brushes.White;
            g.FillRectangle(b, 0, 0, w, h);


            draw(g, pen, brush, 4, 4, w-4, h-4, comboBox1.SelectedIndex);

            preview.Invalidate ();
        }

        private void newMyControlMenu_Click(object sender, EventArgs e)
        {
            MyControl p = new MyControl ();
            p.Parent = pictureBox;
        }


    }
}
